function [theResult, theLineNumber] = get(self)

% batch/get -- Return next line from batch-file.
%  get(self) returns the next line from the current
%   batch-file.
%  [theResult, theLineNumber] = get(self) also returns
%   the current line-number.
 
% Copyright (C) 1999 Dr. Charles R. Denham, ZYDECO.
%  All Rights Reserved.
%   Disclosure without explicit written consent from the
%    copyright owner does not constitute publication.
 
% Version of 18-Oct-1999 13:18:53.
% Updated    19-Oct-1999 10:28:25.

if nargin < 1, help(mfilename), return, end

try
	theBatchFilePtr = self.itsBatchFilePtr;
	batch('__nextlineno__')
	result = fgetl(theBatchFilePtr);
	if isequal(result, -1)
		batch([])
	elseif self.itIsVerbose
		theLineNumber = int2str(lineno(batch));
		while length(theLineNumber) < 3
			theLineNumber = [' ' theLineNumber];
		end
		disp([' ## line ' theLineNumber ': ' result])
	end
catch
	theBatchFile = self.itsBatchFile;
	theLineNumber = int2str(lineno(batch));
	disp([' ## In "' theBatchFile '" at line ' theLineNumber ':'])
	batch([])
	error(' ## Error while reading line.')
end

if nargout > 0
	theResult = result;
	if nargout > 1, theLineNumber = lineno(batch); end
else
	assignin('caller', 'ans', result)
end
