function [theResult, theLineNumber] = run(self)

% batch/run -- Run the batch-file.
%  run(self) runs the batch-file on behalf of self,
%   a "batch" object.  It evaluates command-lines that
%   are non-blank and that do not begin with '%'.
% [theResult, theLineNumber] = run(self) returns the
%   line that was evaluated, and its line-number.
 
% Copyright (C) 1999 Dr. Charles R. Denham, ZYDECO.
%  All Rights Reserved.
%   Disclosure without explicit written consent from the
%    copyright owner does not constitute publication.
 
% Version of 18-Oct-1999 13:06:35.
% Updated    18-Oct-1999 23:19:02.

if nargout > 0, theResult = []; end
if nargin < 1, help(mfilename), return, end

while (1)
	theLine = get(self);
	if isequal(theLine, -1)
		break
	end
	if ~isempty(theLine) & any(theLine ~= ' ')
		if theLine(1) ~= '%'
			try
				eval(theLine)
			catch
				theBatchFile = self.itsBatchFile;
				theLineNumber = int2str(batch('__lineno__'));
				disp([' ## In "' theBatchFile '" at line ' theLineNumber ':'])
				disp([' ## Error while evaluating: ' theLine])
				disp([' ## ' lasterr])
				batch([])
				break
			end
		end
	end
end

if nargout > 0
	theResult = theLine;
	if nargout > 1, theLineNumber = lineno(batch); end
else
	assignin('caller', 'ans', self)
end
