% README -- Batch Processing Toolbox
 
% Copyright (C) 1999 Dr. Charles R. Denham, ZYDECO.
%  All Rights Reserved.
%   Disclosure without explicit written consent from the
%    copyright owner does not constitute publication.
 
% Version of 18-Oct-1999 17:50:04.
% Updated    19-Oct-1999 08:12:52.

Batch Processing Toolbox

The "batch" system runs a sequence of commands, each of which
may be followed by parameter-lines that can be retrieved inside
the routines that are running in batch-mode.

Batch Processing Commands

The Batch-Monitor relies on the "batch" class, of which there
is just one instance that is generated automatically, as
needed.  The calling syntax is limited to just five commands,
each of which calls "batch" itself.

1. batch('aBatchFileName') -- Constructor

This command introduces the given file to the batch process.
The first executable line in the file will be evaluated, after
which any succeeding parameter-lines must be retrieved by the
"get(batch)" command (see below).  When the first command
returns, the next executable line in the batch-file will be
evaluated, and so forth.  The preceeding parameter-lines
must have been fully exhausted by that time, since "batch"
does not itself know how to navigate the parameters.

2. batch([]) or batch('') -- Destructor

This command disables the batch process.  The current batch-file
is closed and the "batch" system is deactivated.  Use this command
only if aborting a batch process.

3. if running(batch), x = get(batch), else, ..., end

This syntax probes the batch-system to see if it is active.
If so, the next line should be retrieved with "get".  Place
this sort of code everywhere a parameter is required.

4. x = get(batch)

This command retrieves the next line in the batch-file and
returns it to the calling function as a string.  If the
returned value is double(-1), then the end-of-file has been
reached, in which case, "batch" will have already closed the
file automatically.

5. x = lineno(batch)

This command returns the number of batch-file lines that
have been processed thus far.

Experimental Syntax (PRIVATE -- DO NOT USE)

1. tell(self) behaves like "ftell()".
2. seek(self, offset, origin) behaves like "fseek()".
3. scan(self, format, size) works like "fscanf()".

These functions are useful for remembering the file-pointer,
looking ahead in the file, then restoring the pointer.  During
such a procedure, do not revert to the "get(batch)" method until
the file-pointer has been restored.

Extensions

Some extensions may be in order, such as one that can scan
to the end of a set of parameter-lines, perhaps by searching
for a keyword, comment, or a blank-line.  Extensions are the
responsibility of the user.  As a simple example, we have
included the "isbatch" function, which calls "running(batch)".

Example

batch batch_file.bch
